@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: center.c,v 1.7 1999/06/08 19:47:31 bazsi Exp $
+ * $Id: center.c,v 1.8 1999/06/10 11:38:57 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -98,11 +98,11 @@ static void do_distribute_log(struct log_handler *c, struct log_info *msg)
 					if (d->type == EP_DESTINATION) {
 						assert(d->ref);
 #if HAVE_PTHREAD_H
-						pthread_lock_mutex(&loglock);
+						pthread_mutex_lock(&loglock);
 #endif
 						HANDLE_LOG(d->ref, msg);
 #if HAVE_PTHREAD_H
-						pthread_unlock_mutex(&loglock);
+						pthread_mutex_unlock(&loglock);
 #endif
 					}
 				}
